@@ -3,19 +3,20 @@
 
 #define FAST_BUILD
 #define ZLIB_FOUND
-/* #undef CUPDLP_CPU */
+#define CUPDLP_CPU
+/* #undef CUPDLP_GPU */
+/* #undef HIPO */
 #define CMAKE_BUILD_TYPE "MacPorts"
-#define CMAKE_INSTALL_PREFIX "/opt/local"
 /* #undef HIGHSINT64 */
 /* #undef HIGHS_NO_DEFAULT_THREADS */
 /* #undef HIGHS_HAVE_MM_PAUSE */
 #define HIGHS_HAVE_BUILTIN_CLZ
 /* #undef HIGHS_HAVE_BITSCAN_REVERSE */
+/* #undef BLAS_LIBRARIES */
 
 #define HIGHS_GITHASH "n/a"
 #define HIGHS_VERSION_MAJOR 1
-#define HIGHS_VERSION_MINOR 8
-#define HIGHS_VERSION_PATCH 1
-#define HIGHS_DIR "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_math_HiGHS/HiGHS/work/HiGHS-1.8.1"
+#define HIGHS_VERSION_MINOR 12
+#define HIGHS_VERSION_PATCH 0
 
 #endif /* HCONFIG_H_ */
